@@ -1,9 +1,4 @@
-require 'rubygems'
-require 'rspec'
-require 'pp'
-
-require 'lib/em-synchrony'
-require 'lib/em-synchrony/em-http'
+require 'spec/helper/core'
 require 'lib/em-synchrony/mysql2'
 require 'lib/em-synchrony/em-remcached'
 require 'lib/em-synchrony/em-memcache'
@@ -19,4 +14,6 @@ def now(); Time.now.to_f; end
 
 RSpec.configure do |config|
   config.include(Sander6::CustomMatchers)
+
+  config.filter_run_excluding ci_skip: true if ENV['CI']
 end
